@@ -9,9 +9,12 @@
 /* Define if mhash should be used */
 #undef WITH_MHASH
  
+/* Define if PostgrsSQL should used */
+#undef WITH_PSQL
+ 
 /* Define if zlib.h is present */
 #undef HAVE_ZLIB_H
- 
+
 /* syslog() available? */
 #undef HAVE_SYSLOG
 
