@@ -1,6 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
- * Copyright (C) 1999 Rami Lehti, Pablo Virolainen
+ * Copyright (C) 1999,2000 Rami Lehti, Pablo Virolainen
+ * $Header: /cvs-root-aide/aide/include/db_config.h,v 1.32 2000/04/20 12:44:50 rammer Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,9 +21,24 @@
 #ifndef _DB_CONFIG_H_INCLUDED
 #define _DB_CONFIG_H_INCLUDED
 #include <sys/types.h>
+#include "config.h"
 #include "types.h"
 #include "list.h"
 
+#ifdef WITH_PSQL
+#include "libpq-fe.h"
+
+typedef struct psql_data{
+  PGconn* conn;
+  char* table;
+} psql_data;
+
+#endif
+
+#ifdef WITH_ZLIB
+#include <zlib.h>
+#endif
+
 #define RETOK 0
 #define RETFAIL -1
 
@@ -30,7 +46,8 @@
 #define DO_COMPARE  (1<<1)
 
 typedef enum {
-  url_file, url_stdout, url_stdin, url_stderr, url_fd ,url_unknown
+  url_file, url_stdout, url_stdin, url_stderr, url_fd, url_http
+  ,url_sql, url_unknown 
 } URL_TYPE;
 
 
@@ -41,10 +58,10 @@ typedef struct url_t {
 } url_t;
 
 
-typedef enum { db_filename, db_perm, db_uid, db_gid,
+typedef enum { db_filename, db_linkname, db_perm, db_uid, db_gid,
 	       db_size, db_atime, db_ctime, db_mtime, db_inode,
 	       db_bcount, db_lnkcount, db_md5, db_sha1, db_rmd160,
-	       db_tiger, db_crc32, db_haval, db_rmd128, db_snefru,
+	       db_tiger, db_crc32, db_haval,
 	       db_gost, db_crc32b, db_unknown } DB_FIELD;
 
 /* db_unknown must be last because it is used to determine size of
@@ -52,28 +69,27 @@ typedef enum { db_filename, db_perm, db_uid, db_gid,
 
 /* WE need this for rx_rules since enums are not orrable (horrible) */
 #define DB_FILENAME (1<<0)
-#define DB_PERM     (1<<1)
-#define DB_UID      (1<<2)
-#define DB_GID      (1<<3)
-#define DB_SIZE     (1<<4)
-#define DB_SIZEG    (1<<5)
-#define DB_ATIME    (1<<6)
-#define DB_CTIME    (1<<7)
-#define DB_MTIME    (1<<8)
-#define DB_INODE    (1<<9)
-#define DB_BCOUNT   (1<<10)
-#define DB_LNKCOUNT (1<<11)
-#define DB_MD5      (1<<12)
-#define DB_SHA1     (1<<13)
-#define DB_RMD160   (1<<14)
-#define DB_TIGER    (1<<15)
+#define DB_LINKNAME (1<<1)
+#define DB_PERM     (1<<2)
+#define DB_UID      (1<<3)
+#define DB_GID      (1<<4)
+#define DB_SIZE     (1<<5)
+#define DB_SIZEG    (1<<6)
+#define DB_ATIME    (1<<7)
+#define DB_CTIME    (1<<8)
+#define DB_MTIME    (1<<9)
+#define DB_INODE    (1<<10)
+#define DB_BCOUNT   (1<<11)
+#define DB_LNKCOUNT (1<<12)
+#define DB_MD5      (1<<13)
+#define DB_SHA1     (1<<14)
+#define DB_RMD160   (1<<15)
+#define DB_TIGER    (1<<16)
 #ifdef WITH_MHASH
-#define DB_CRC32    (1<<16)
-#define DB_HAVAL    (1<<17)
-#define DB_RMD128   (1<<18)
-#define DB_SNEFRU   (1<<19)
-#define DB_GOST     (1<<20)
-#define DB_CRC32B   (1<<21)
+#define DB_CRC32    (1<<17)
+#define DB_HAVAL    (1<<18)
+#define DB_GOST     (1<<19)
+#define DB_CRC32B   (1<<20)
 #endif
 
 /* TIMEBUFSIZE should be exactly ceil(sizeof(time_t)*8*ln(2)/ln(10))
@@ -85,17 +101,24 @@ typedef enum { db_filename, db_perm, db_uid, db_gid,
 
 typedef struct db_config {
   url_t* db_in_url;
-  FILE* db_in;
+  void* db_in;
   
   url_t* db_out_url;
-  FILE* db_out;
+  void* db_out;
   
+#ifdef WITH_ZLIB
+  gzFile db_gzin;
+  gzFile db_gzout;
+  /* Is dbout gzipped or not */
+  int gzip_dbout;
+  
+#endif
+
   int db_in_size;
   DB_FIELD* db_in_order;
 
   int db_out_size;
   DB_FIELD* db_out_order;
-
   
   char* config_file;
 
@@ -126,6 +149,8 @@ typedef struct db_config {
   time_t start_time;
   time_t end_time;
 
+  int symlinks_found;
+
 } db_config;
 
 typedef struct db_line {
@@ -136,8 +161,6 @@ typedef struct db_line {
 #ifdef WITH_MHASH
   byte* crc32;
   byte* haval;
-  byte* rmd128;
-  byte* snefru;
   byte* gost;
   byte* crc32b;
 #endif
@@ -156,6 +179,7 @@ typedef struct db_line {
   off_t size_o; /* ... */
   unsigned long bcount;
   char* filename;
+  char* linkname;
 
   /* Attribuutes .... */
   int attr;
