@@ -2,6 +2,7 @@
  *	Copyright (C) 1998 Free Software Foundation, Inc.
  *
  * This file was part of GNUPG.
+ * $Header: /cvs-root-aide/aide/include/types.h,v 1.5 2000/04/20 12:44:53 rammer Exp $
  *
  * GNUPG is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -91,7 +92,7 @@
   #elif SIZEOF_UNSIGNED_LONG == 8
     typedef unsigned long u64;
     #define HAVE_U64_TYPEDEF
-  #elif __GNUC__ >= 2 || defined(__SUNPRO_C)
+  #elif __GNUC__ >= 2 || defined(__SUNPRO_C) || defined(_AIX) && defined(_LONGLONG)
     typedef unsigned long long u64;
     #define HAVE_U64_TYPEDEF
   #endif
