@@ -1,6 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
- * Copyright (C) 1999 Rami Lehti, Pablo Virolainen
+ * Copyright (C) 1999,2000 Rami Lehti, Pablo Virolainen
+ * $Header: /cvs-root-aide/aide/src/aide.c,v 1.45 2000/04/20 12:44:54 rammer Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -237,12 +238,17 @@ void setdefaults_before_config()
   conf->db_out_order=(DB_FIELD*)malloc(sizeof(DB_FIELD)*db_unknown);
   conf->db_out_size=1;
   conf->db_out_order[0]=db_filename;
+  conf->symlinks_found=0;
   conf->db_in_size=0;
   conf->db_in_order=NULL;
   conf->db_in_url=NULL;
   conf->db_in=NULL;
   conf->db_out_url=NULL;
   conf->db_out=NULL;
+#ifdef WITH_ZLIB
+  conf->gzip_dbout=0;
+#endif
+
   conf->action=0;
   conf->catch_mmap=0;
 
@@ -272,7 +278,6 @@ void setdefaults_before_config()
   do_groupdef("sha1",DB_SHA1);
   do_groupdef("rmd160",DB_RMD160);
 #ifdef WITH_MHASH
-  do_groupdef("rmd128",DB_RMD128);
   do_groupdef("crc32",DB_CRC32);
   /*
     crc32b is same than crc32
@@ -280,7 +285,6 @@ void setdefaults_before_config()
   */
   do_groupdef("haval",DB_HAVAL);
   do_groupdef("gost",DB_GOST);
-  do_groupdef("snefru",DB_SNEFRU); 
 #endif
 
   do_groupdef("R",DB_PERM|DB_INODE|DB_LNKCOUNT|DB_UID|DB_GID|DB_SIZE|
