@@ -1,6 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
- * Copyright (C) 1999 Rami Lehti
+ * Copyright (C) 1999,2000 Rami Lehti, Pablo Virolainen
+ * $Header: /cvs-root-aide/aide/src/commandconf.c,v 1.40 2000/04/20 12:44:55 rammer Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -214,12 +215,6 @@ void update_db_out_order(int a)
   if((a&DB_HAVAL) && (check_dboo(db_haval)!=RETFAIL)){
     conf->db_out_order[conf->db_out_size++]=db_haval;
   }
-  if((a&DB_RMD128) && (check_dboo(db_rmd128)!=RETFAIL)){
-    conf->db_out_order[conf->db_out_size++]=db_rmd128;
-  }
-  if((a&DB_SNEFRU) && (check_dboo(db_snefru)!=RETFAIL)){
-    conf->db_out_order[conf->db_out_size++]=db_snefru;
-  }
   if((a&DB_GOST) && (check_dboo(db_gost)!=RETFAIL)){
     conf->db_out_order[conf->db_out_size++]=db_gost;
   }
@@ -262,6 +257,9 @@ void putbackvariable(char* var)
     conf_put_token(a);
   }
   else {
+    
+    error(230,"Variable %s not defined\n",tmp);
+
     /*
      * We can use nondefined variable
      */ 
