@@ -1,6 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
- * Copyright (C) 1999 Rami Lehti, Pablo Virolainen
+ * Copyright (C) 1999,2000 Rami Lehti, Pablo Virolainen
+ * $Header: /cvs-root-aide/aide/src/compare_db.c,v 1.34 2000/04/20 12:44:55 rammer Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,6 +22,7 @@
 #include <string.h>
 #include <time.h>
 #include <sys/stat.h>
+
 #include "base64.h"
 #include "report.h"
 #include "db_config.h"
@@ -30,6 +32,8 @@
 #include "list.h"
 #include "db.h"
 #include "util.h"
+#include "commandconf.h"
+#include "gen_list.h"
 
 #ifdef WITH_MHASH
 #include <mhash.h>
@@ -84,7 +88,19 @@ int compare_md_entries(byte* e1,byte* e2,int len)
 
 int compare_lines(db_line* l1,db_line* l2,int ignorelist)
 {
-  
+
+  if (!(DB_LINKNAME&ignorelist)) {
+    if(l1->linkname==NULL){
+      if(l2->linkname!=NULL){
+	return RETFAIL;
+      }
+    }else if(l2->linkname==NULL){
+      return RETFAIL;
+    }else if(strcmp(l1->linkname,l2->linkname)!=0){
+      return RETFAIL;
+    }
+  }
+    
   if (!(DB_SIZEG&ignorelist)) {
     if ( (DB_SIZEG&l2->attr) && !(DB_SIZE&l2->attr) ){
       if(l1->size>l2->size){
@@ -184,25 +200,11 @@ int compare_lines(db_line* l1,db_line* l2,int ignorelist)
   
   if (!(DB_HAVAL&ignorelist)) {
     if(compare_md_entries(l1->haval,l2->haval,
-			  mhash_get_block_size(MHASH_HAVAL))==RETFAIL){
+			  mhash_get_block_size(MHASH_HAVAL256))==RETFAIL){
       return RETFAIL;
     }
   }
-  
-  if (!(DB_RMD128&ignorelist)) {
-    if(compare_md_entries(l1->rmd128,l2->rmd128,
-			  mhash_get_block_size(MHASH_RIPEMD128))==RETFAIL){
-      return RETFAIL;
-    }
-  }
-  
-  if (!(DB_SNEFRU&ignorelist)) {
-    if(compare_md_entries(l1->snefru,l2->snefru,
-			  mhash_get_block_size(MHASH_SNEFRU))==RETFAIL){
-      return RETFAIL;
-    }
-  }
-  
+    
   if (!(DB_GOST&ignorelist)) {
     if(compare_md_entries(l1->gost,l2->gost,
 			  mhash_get_block_size(MHASH_GOST))==RETFAIL){
@@ -222,6 +224,20 @@ int compare_lines(db_line* l1,db_line* l2,int ignorelist)
   return RETOK;
 }
 
+void print_lname_changes(char*old,char*new)
+{
+  if(old==NULL){
+    if(new!=NULL){
+      error(5,"Linkname: old = <NULL> , new = %s\n",new);
+    }
+  }else if(new==NULL){
+    error(5,"Linkname: old = %s , new = <NULL>\n",old);
+  }else if(strcmp(old,new)!=0){
+    error(5,"Linkname: old = %s , new = %s\n",
+	  old,new);
+  }
+}
+
 void print_md_changes(byte*old,byte*new,int len,char* fnam)
 {
   if(old!=NULL && new!=NULL){
@@ -281,6 +297,10 @@ void print_dbline_changes(db_line* old,db_line* new,int ignorelist)
 
   error(5,"\nFile: %s\n",old->filename);
 
+  if(!(DB_LINKNAME&ignorelist)){
+    print_lname_changes(old->linkname,new->linkname);
+  }
+
   if (!(DB_SIZE&ignorelist)) {
     if(old->size!=new->size){
       error(5,"Size: old = %u , new = %u\n",
@@ -385,22 +405,10 @@ void print_dbline_changes(db_line* old,db_line* new,int ignorelist)
 
   if (!(DB_HAVAL&ignorelist)) {
     print_md_changes(old->haval,new->haval,
-		     mhash_get_block_size(MHASH_HAVAL),
+		     mhash_get_block_size(MHASH_HAVAL256),
 		     "HAVAL");
   }
   
-  if (!(DB_RMD128&ignorelist)) {
-    print_md_changes(old->rmd128,new->rmd128,
-		     mhash_get_block_size(MHASH_RIPEMD128),
-		     "RMD128");
-  }
-
-  if (!(DB_SNEFRU&ignorelist)) {
-    print_md_changes(old->snefru,new->snefru,
-		     mhash_get_block_size(MHASH_SNEFRU),
-		     "SNEFRU");
-  }
-  
   if (!(DB_GOST&ignorelist)) {
     print_md_changes(old->gost,new->gost,
 		     mhash_get_block_size(MHASH_GOST),
@@ -428,15 +436,11 @@ void free_db_line(db_line* dl)
   free(dl->crc32b);
   free(dl->gost);
   free(dl->haval);
-  free(dl->rmd128);
-  free(dl->snefru);
 
   dl->crc32=NULL;
   dl->crc32b=NULL;
   dl->gost=NULL;
   dl->haval=NULL;
-  dl->rmd128=NULL;
-  dl->snefru=NULL;
 #endif
 
 
@@ -488,26 +492,23 @@ void init_rxlst(list* rxlst)
 
 }
 
-list* eat_files_indir(list* flist,char* dirname,long* filcount)
+void eat_files_indir(list* flist,char* dirname,long* filcount)
 {
-  list* r=NULL;
-  list* last=flist;
+  size_t len;
 
   *filcount=0;
+  len=strlen(dirname);
 
-  for(r=flist;r;r=r->next){
-    if((strlen(((db_line*)r->data)->filename)>=strlen(dirname)) && 
-       (strncmp(dirname,((db_line*)r->data)->filename,strlen(dirname)-1)==0)
-       && ((((db_line*)r->data)->filename)[strlen(dirname)]=='/')){
-      free_db_line((db_line*)r->data);
-      free(r->data);
-      r=list_delete_item(r);
-      last=r;
+  while (flist){
+    if((strncmp(dirname,((db_line*)flist->data)->filename,len)==0)
+       && ((((db_line*)flist->data)->filename)[len]=='/')){
+      free_db_line((db_line*)flist->data);
+      free(flist->data);
+      flist=list_delete_item(flist);
       (*filcount)++;
     }
+    flist=flist->next;
   }
-
-  return last;
 }
 
 void compare_db(list* new,db_config* conf)
@@ -559,9 +560,9 @@ void compare_db(list* new,db_config* conf)
       /* FIXME There should be a check for this in changed part also */
       /* This part should also be rethinked */
       if(!initdbwarningprinted &&
-	 (!check_list_for_match(conf->selrxlst,old->filename,&tempignore) ||
-	  !check_list_for_match(conf->equrxlst,old->filename,&tempignore)) &&
-	 check_list_for_match(conf->negrxlst,old->filename,&tempignore)){
+	 (check_list_for_match(conf->selrxlst,old->filename,&tempignore) ||
+	  check_list_for_match(conf->equrxlst,old->filename,&tempignore)) &&
+	 !check_list_for_match(conf->negrxlst,old->filename,&tempignore)){
 	if(!(conf->action&DO_INIT)){
 	  error(5,"WARNING: Old db contains a file that shouldn\'t be there, run --init or --update\n");
 	}
@@ -619,7 +620,7 @@ void compare_db(list* new,db_config* conf)
 	    /*	    free_db_line((db_line*)r->data);
 	    free(r->data);
 	    r=list_delete_item(r);*/
-	    r=eat_files_indir(r,((db_line*)r->data)->filename,&filesindir);
+	    eat_files_indir(r->next,((db_line*)r->data)->filename,&filesindir);
 	    if(filesindir>0){
 	      error(5,
 		    "added: THERE WERE ALSO %li "
