@@ -25,7 +25,7 @@
 #include <errno.h>
 #include <assert.h>
 #include "cipher.h"
-#include "error.h"
+#include "report.h"
 #include "rmd.h"
 
 
