@@ -1,6 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
- * Copyright (C) 1999 Rami Lehti
+ * Copyright (C) 1999,2000 Rami Lehti, Pablo Virolainen
+ * $Header: /cvs-root-aide/aide/src/db.c,v 1.33 2000/04/20 12:44:56 rammer Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,10 +24,17 @@
 #include <errno.h>
 #include "db.h"
 #include "db_file.h"
+
+#ifdef WITH_PSQL
+#include "db_sql.h"
+#endif
+
 #include "db_config.h"
 #include "report.h"
 #include "be.h"
 
+#include "cipher.h"
+
 #ifdef WITH_MHASH
 #include <mhash.h>
 #endif
@@ -46,14 +54,20 @@ int db_init(db_config* conf,int inout)
   error(200,"db_init %i\n",inout);
 
   if(inout==1){
-    conf->db_in=be_init(1,conf->db_in_url);
+    conf->db_in=be_init(1,conf->db_in_url,0);
     if(conf->db_in==NULL) {
       return RETFAIL;
     }
     return RETOK;
   }
   if(inout==0){
-    conf->db_out=be_init(0,conf->db_out_url);
+
+#ifdef WITH_ZLIB
+    conf->db_out=be_init(0,conf->db_out_url,conf->gzip_dbout);
+#else 
+    conf->db_out=be_init(0,conf->db_out_url,0);
+#endif
+    
     if(conf->db_out==NULL){
       error(200,"db_out is null\n");
       return RETFAIL;
@@ -89,7 +103,7 @@ db_line* db_readline(db_config* conf){
 	
       }
     }
-      
+    
     break;
   }
   default : {
@@ -110,7 +124,6 @@ byte* base64tobyte(char* src,int len)
   return NULL;
 }
 
-
 db_line* db_char2line(char** ss,db_config* conf){
 
   int i;
@@ -124,8 +137,6 @@ db_line* db_char2line(char** ss,db_config* conf){
   line->crc32=NULL;
   line->crc32b=NULL;
   line->haval=NULL;
-  line->rmd128=NULL;
-  line->snefru=NULL;
   line->gost=NULL;
 #endif
   line->perm=0;
@@ -139,6 +150,7 @@ db_line* db_char2line(char** ss,db_config* conf){
   line->bcount=0;
   line->size=0;
   line->filename=NULL;
+  line->linkname=NULL;
   line->attr=0;
 
   for(i=0;i<conf->db_in_size;i++){
@@ -153,6 +165,27 @@ db_line* db_char2line(char** ss,db_config* conf){
       }
       break;
     }
+    case db_linkname : {
+      if(ss[conf->db_in_order[i]]!=NULL){
+	if(ss[conf->db_in_order[i]][0]=='0'){
+	  if(ss[conf->db_in_order[i]][1]=='\0'){
+	    line->linkname=NULL;
+	    break;
+	  }else if(ss[conf->db_in_order[i]][1]=='-'){
+	    line->linkname=strdup("");
+	    break;
+	  }else if(ss[conf->db_in_order[i]][1]=='0'){
+	    ss[conf->db_in_order[i]]++;
+	  }
+	}
+	decode_string(ss[conf->db_in_order[i]]);
+	line->linkname=strdup(ss[conf->db_in_order[i]]);
+      } else {
+	error(0,"db_char2line():Error while reading database\n");
+	abort();
+      }
+      break;
+    }
     case db_mtime : {
       line->mtime=base64totime_t(ss[conf->db_in_order[i]]);
       break;
@@ -222,16 +255,6 @@ db_line* db_char2line(char** ss,db_config* conf){
 			       strlen(ss[conf->db_in_order[i]]));
       break;
     }
-    case db_rmd128 : {
-      line->rmd128=base64tobyte(ss[conf->db_in_order[i]],
-			       strlen(ss[conf->db_in_order[i]]));
-      break;
-    }
-    case db_snefru : {
-      line->snefru=base64tobyte(ss[conf->db_in_order[i]],
-			       strlen(ss[conf->db_in_order[i]]));
-      break;
-    }
     case db_crc32b : {
       line->crc32b=base64tobyte(ss[conf->db_in_order[i]],
 			       strlen(ss[conf->db_in_order[i]]));
@@ -321,6 +344,16 @@ int db_writespec(db_config* conf)
     }
     break;
   }
+#ifdef WITH_PSQL
+  case url_sql: {
+    if(conf->db_out!=NULL){
+      if(db_writespec_sql(conf)==RETOK){
+	return RETOK;
+      }
+    }
+    break;
+  }
+#endif
   default:{
     error(0,"Unknown output in db out.\n");    
     return RETFAIL;
@@ -329,7 +362,6 @@ int db_writespec(db_config* conf)
   return RETFAIL;
 }
 
-
 int db_writeline(db_line* line,db_config* conf){
 
   if (line==NULL||conf==NULL) return 0;
@@ -343,17 +375,26 @@ int db_writeline(db_line* line,db_config* conf){
       if (db_writeline_file(line,conf)==RETOK) {
 	return RETOK;
       }
-    };
+    }
     return RETFAIL;
     break;
   }
+#ifdef WITH_PSQL
+  case url_sql: {
+    if (conf->db_out!=NULL) {
+      if (db_writeline_sql(line,conf)==RETOK) {
+	return RETOK;
+      }
+    }
+    return RETFAIL;
+    break;
+  }
+#endif
   default : {
     error(0,"Unknown output in db out.\n");    
     return RETFAIL;
   } 
   }
-  
-  
   return RETFAIL;
 }
 
