@@ -1,6 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
- * Copyright (C) 1999 Rami Lehti, Pablo Virolainen
+ * Copyright (C) 1999,2000 Rami Lehti, Pablo Virolainen
+ * $Header: /cvs-root-aide/aide/src/db_file.c,v 1.45 2000/04/20 12:44:56 rammer Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,38 +24,101 @@
 #include <stdlib.h>
 #include <time.h>
 
+#include <errno.h>
+
 #include "types.h"
 #include "base64.h"
 #include "db_file.h"
 #include "conf_yacc.h"
 #include "util.h"
 #include "aide.h"
+#include "commandconf.h"
 
 #ifdef WITH_MHASH
 #include <mhash.h>
 #endif
 
+#ifdef WITH_ZLIB
+#include <zlib.h>
+#endif
+
 #include "cipher.h"
 
 extern int db_scan(); /* Rumaa.... */
 extern char* dbtext; /* Todella rumaa... */
 extern long db_lineno;
 
-const static char* db_names[] = {
-  "name", "bcount", "perm", "uid", "gid", "size", "atime", "ctime",
+char* db_names[] = {
+  "name", "lname" , "bcount", "perm", "uid", "gid", "size", "atime", "ctime",
   "mtime", "inode", "count", "md5", "sha1", "rmd160", "tiger",
-  "crc32", "haval", "rmd128","snefru","gost","crc32b", "unknown" }; 
+  "crc32", "haval","gost","crc32b", "unknown" }; 
 
 const static int db_value[] = {
-  db_filename, db_bcount, db_perm, db_uid, db_gid, db_size, db_atime,
-  db_ctime, db_mtime, db_inode, db_lnkcount, db_md5, db_sha1,
-  db_rmd160, db_tiger, db_crc32, db_haval, db_rmd128, db_snefru,
+  db_filename, db_linkname, db_bcount, db_perm, db_uid, db_gid,
+  db_size, db_atime, db_ctime, db_mtime, db_inode, db_lnkcount,
+  db_md5, db_sha1, db_rmd160, db_tiger, db_crc32, db_haval,
   db_gost, db_crc32b,
   db_unknown };
 
 
 extern void db_buff(FILE*);
 
+#ifdef WITH_ZLIB
+#define ZBUFSIZE 16384
+
+void handle_gzipped_input(int out){
+
+  int nread=0;
+  int err=0;
+  int* buf=malloc(ZBUFSIZE);
+  buf[0]='\0';
+  error(200,"handle_gzipped_input(),%d\n",out);
+  while(!gzeof(conf->db_gzin)){
+    if((nread=gzread(conf->db_gzin,buf,ZBUFSIZE))<0){
+      error(0,"gzread() failed!\n");
+      exit(1);
+    } else {
+      /* gzread returns 0 even if uncompressed bytes were read*/
+      if(nread==0){
+	write(out, buf,strlen((char*)buf));
+      } else {
+	write(out, buf,nread);
+      }
+      error(240,"nread=%d,strlen(buf)=%d,errno=%s,gzerr=%s\n",
+	    nread,strlen((char*)buf),strerror(errno),
+	    gzerror(conf->db_gzin,&err));
+      buf[0]='\0';
+    }
+  }
+  close(out);
+  error(240,"handle_gzipped_input() exiting\n");
+  exit(0);
+  /* NOT REACHED */
+  return;
+}
+void handle_gzipped_output(int in) {
+  FILE*fh=NULL;
+  int*buf=malloc(ZBUFSIZE);
+  int nread=0;
+  
+  fh=fdopen(in,"rb");
+
+  error(200,"handle_gzipped_ouput()\n");
+  while(!feof(fh)){
+    nread=fread(buf,1,ZBUFSIZE,fh);
+    gzwrite(conf->db_gzout,buf,nread);
+
+  }
+  gzclose(conf->db_gzout);
+
+  error(200,"handle_gzipped_ouput(),exiting\n");
+  exit(0);
+  /* NOT REACHED */
+  return;
+}
+
+#endif
+
 int db_file_read_spec(db_config* conf){
   
   int i=0;
@@ -124,7 +188,56 @@ char** db_readline_file(db_config* conf){
     db_buff(conf->db_in);
     
     token=db_scan();
-    while(token==TUNKNOWN){
+    while((token!=TDBSPEC)){
+
+      switch(token){
+      case TUNKNOWN: {
+	continue;
+	break;
+      }
+      case TGZIPHEADER: {
+
+#ifndef WITH_ZLIB
+	error(0,"Zlib support is not compiled in.\n");
+	return NULL;
+#else
+	int pipefd[2];
+	pid_t retval=0;
+	/* Is this safe? Can we always fseek back? Probably.*/
+	fseek(conf->db_in,0L,SEEK_SET);
+	if(pipe(pipefd)<0){
+	  error(0,"Couldn't open a pipe for zipped input\n");
+	  return NULL;
+	}
+	if((retval=fork())==0){
+	  /* The child process */
+	  close(pipefd[0]);
+	  conf->db_gzin=gzdopen(fileno(conf->db_in),"rb");
+	  /* WARNING This causes weird problems. Don't do it.
+	     fclose(conf->db_in);
+	  */
+	  handle_gzipped_input(pipefd[1]);
+	} else {
+	  /* The parent */
+	  fclose(conf->db_in);
+	  conf->db_in=fdopen(pipefd[0],"r");
+	  db_buff(conf->db_in);
+	  close(pipefd[1]);
+	}
+#endif
+	break;
+      }
+      default: {
+	/* If it is anything else we quit */
+	/* Missing dbspec */
+	token=TEOF;
+	break;
+      }
+      }
+      if(token==TEOF){
+	break;
+      }
+
       token=db_scan();
     }
 
@@ -239,10 +352,14 @@ char** db_readline_file(db_config* conf){
       return NULL;
       break;
     }
+    case TERROR : {
+      error(0,"There was an error in the database file on line:%i.\n",db_lineno);
+      break;
+    }
     
     default : {
       
-      error(0,"Not implemented %i\n\"%s\"",r,dbtext);
+      error(0,"Not implemented in db_readline_file %i\n\"%s\"",r,dbtext);
       
       free(s);
       s=NULL;
@@ -286,6 +403,22 @@ int db_writechar(char* s,FILE* file,int i)
     fprintf(file," ");
   }
 
+  if(s==NULL){
+    retval=fprintf(file,"0");
+    return retval;
+  }
+  if(s[0]=='\0'){
+    retval=fprintf(file,"0-");
+    return retval;
+  }
+  if(s[0]=='0'){
+    retval=fprintf(file,"00");
+    if(retval<0){
+      return retval;
+    }
+    s++;
+  }
+
   r=CLEANDUP(s);
   retval=fprintf(file,"%s",r);
   free(r);
@@ -380,7 +513,7 @@ int db_writespec_file(db_config* conf)
 
   retval=fprintf(conf->db_out,
 		 "# This file was generated by Aide, version %s\n"
-		 "# Time of generation was %0.4u-%0.2u-%0.2u %0.2u:%0.2u:%0.2u\n",
+		 "# Time of generation was %.4u-%.2u-%.2u %.2u:%.2u:%.2u\n",
 		 AIDEVERSION,
 		 st->tm_year+1900, st->tm_mon+1, st->tm_mday,
 		 st->tm_hour, st->tm_min, st->tm_sec
@@ -420,6 +553,10 @@ int db_writeline_file(db_line* line,db_config* conf){
       db_writechar(line->filename,conf->db_out,i);
       break;
     }
+    case db_linkname : {
+      db_writechar(line->linkname,conf->db_out,i);
+      break;
+    }
     case db_bcount : {
       db_writeint(line->bcount,conf->db_out,i);
       break;
@@ -498,19 +635,7 @@ int db_writeline_file(db_line* line,db_config* conf){
     }
     case db_haval : {
       db_write_byte_base64(line->haval,
-			   mhash_get_block_size(MHASH_HAVAL),
-			   conf->db_out,i);
-      break;
-    }
-    case db_rmd128 : {
-      db_write_byte_base64(line->rmd128,
-			   mhash_get_block_size(MHASH_RIPEMD128),
-			   conf->db_out,i);
-      break;
-    }
-    case db_snefru : {
-      db_write_byte_base64(line->snefru,
-			   mhash_get_block_size(MHASH_SNEFRU),
+			   mhash_get_block_size(MHASH_HAVAL256),
 			   conf->db_out,i);
       break;
     }
