@@ -1,6 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
- * Copyright (C) 1999 Rami Lehti
+ * Copyright (C) 1999,2000 Rami Lehti and Pablo Virolainen
+ * $Header: /cvs-root-aide/aide/src/error.c,v 1.16 2000/04/20 12:44:58 rammer Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -52,7 +53,7 @@ int error_init(url_t* url)
     
   }
   
-  fh=be_init(0,url);
+  fh=be_init(0,url,0);
   if(fh!=NULL) {
     conf->report_fd=list_append(conf->report_fd,(void*)fh);
     conf->report_url=list_append(conf->report_url,(void*)url);
