@@ -1,7 +1,7 @@
-
 /* aide, Advanced Intrusion Detection Environment
  *
- * Copyright (C) 1999 Rami Lehti,Pablo Virolainen
+ * Copyright (C) 1999,2000 Rami Lehti,Pablo Virolainen
+ * $Header: /cvs-root-aide/aide/src/gen_list.c,v 1.62 2000/04/20 12:44:58 rammer Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -36,6 +36,7 @@
 #include "gen_list.h"
 #include "seltree.h"
 #include "db_config.h"
+#include "report.h"
 
 #define CLOCK_SKEW 5
 
@@ -84,6 +85,25 @@ char* strrxtok(char* rx)
   return p;
 }
 
+char* strlastslash(char*str)
+{
+  char* p=NULL;
+  int lastslash=1;
+  int i=0;
+
+  for(i=1;i<strlen(str);i++){
+    if(str[i]=='/'){
+      lastslash=i;
+    }
+  }
+  
+  p=(char*)malloc(sizeof(char)*lastslash+1);
+  strncpy(p,str,lastslash);
+  p[lastslash]='\0';
+
+  return p;
+}
+
 seltree* get_seltree_node(seltree* tree,char* path)
 {
   seltree* node=NULL;
@@ -93,7 +113,7 @@ seltree* get_seltree_node(seltree* tree,char* path)
     return NULL;
   }
 
-  if(strncmp(path,tree->path,strlen(path))==0){
+  if(strncmp(path,tree->path,strlen(path)+1)==0){
     return tree;
   }
   else{
@@ -107,7 +127,7 @@ seltree* get_seltree_node(seltree* tree,char* path)
   return NULL;
 }
 
-seltree* new_seltree_node(seltree* tree,char*path)
+seltree* new_seltree_node(seltree* tree,char*path,int isrx)
 {
   seltree* node=NULL;
   seltree* parent=NULL;
@@ -120,9 +140,17 @@ seltree* new_seltree_node(seltree* tree,char*path)
   node->equ_rx_lst=NULL;
   node->checked=0;
   if(tree!=NULL){
-    parent=get_seltree_node(tree,strrxtok(path));
+    if(isrx){
+      parent=get_seltree_node(tree,strrxtok(path));
+    }else {
+      parent=get_seltree_node(tree,strlastslash(path));
+    }      
     if(parent==NULL){
-      parent=new_seltree_node(tree,strrxtok(path));
+      if(isrx){
+	parent=new_seltree_node(tree,strrxtok(path),isrx);
+      }else {
+	parent=new_seltree_node(tree,strlastslash(path),isrx);
+      }
     }
     
     parent->childs=list_append(parent->childs,(void*)node);
@@ -147,7 +175,7 @@ void gen_seltree(list* rxlist,seltree* tree,char type){
     rxtok=strrxtok(((rx_rule*)r->data)->rx);
     curnode=get_seltree_node(tree,rxtok);
     if(curnode==NULL){
-      curnode=new_seltree_node(tree,rxtok);
+      curnode=new_seltree_node(tree,rxtok,1);
     }
     
     /* We have to add '^' to the first charaster of string... 
@@ -250,9 +278,52 @@ list* add_file_to_list(list* listp,char*filename,int attr,int* addok)
       error(CLOCK_SKEW,"%s ctime in future\n",fil->filename);
     }
   }
+
   
   fil->perm_o=fs.st_mode;
   fil->size_o=fs.st_size;
+
+  if(S_ISLNK(fs.st_mode)){
+    char* lnktmp=NULL;
+    char* lnkbuf=NULL;
+    int len=0;
+
+    if(conf->symlinks_found==0){
+      int it=0;
+      DB_FIELD dbtmp;
+      DB_FIELD dbtmp2;
+      dbtmp=conf->db_out_order[1];
+      conf->db_out_order[1]=db_linkname;
+      for(it=2;it<conf->db_out_size;it++){
+	dbtmp2=conf->db_out_order[it];
+	conf->db_out_order[it]=dbtmp;
+	dbtmp=dbtmp2;
+      }
+      conf->db_out_order[conf->db_out_size++]=dbtmp;
+      conf->symlinks_found=1;
+    }
+
+    lnktmp=(char*)malloc(_POSIX_PATH_MAX+1);
+    if(lnktmp==NULL){
+      error(0,"malloc failed in add_file_to_list()\n");
+      abort();
+    }
+ 
+    len=readlink(fil->filename,lnktmp,_POSIX_PATH_MAX+1);
+    lnkbuf=(char*)malloc(len+1);
+    if(lnkbuf==NULL){
+      error(0,"malloc failed in add_file_to_list()\n");
+      abort();
+    }
+
+    strncpy(lnkbuf,lnktmp,len);
+    lnkbuf[len]='\0';
+    fil->linkname=lnkbuf;
+    free(lnktmp);
+  }else {
+    fil->linkname=NULL;
+  }
+
   
   if(DB_INODE&attr){
     fil->inode=fs.st_ino;
@@ -316,7 +387,7 @@ list* add_file_to_list(list* listp,char*filename,int attr,int* addok)
 
   if(S_ISDIR(fs.st_mode)||S_ISCHR(fs.st_mode)
      ||S_ISBLK(fs.st_mode)||S_ISFIFO(fs.st_mode)
-     ||S_ISLNK(fs.st_mode)){
+     ||S_ISLNK(fs.st_mode)||S_ISSOCK(fs.st_mode)){
     fil->md5=NULL;
     fil->sha1=NULL;
     fil->tiger=NULL;
@@ -325,24 +396,20 @@ list* add_file_to_list(list* listp,char*filename,int attr,int* addok)
     fil->crc32=NULL;
     fil->crc32b=NULL;
     fil->haval=NULL;
-    fil->rmd128=NULL;
-    fil->snefru=NULL;
     fil->gost=NULL;
 #endif
   }else {
     /* 1 if needs to be set
      * 0 otherwise */
-    fil->md5=DB_MD5&attr?"":NULL;
-    fil->sha1=DB_SHA1&attr?"":NULL;
-    fil->tiger=DB_TIGER&attr?"":NULL;
-    fil->rmd160=DB_RMD160&attr?"":NULL;
+    fil->md5=DB_MD5&attr?(byte*)"":NULL;
+    fil->sha1=DB_SHA1&attr?(byte*)"":NULL;
+    fil->tiger=DB_TIGER&attr?(byte*)"":NULL;
+    fil->rmd160=DB_RMD160&attr?(byte*)"":NULL;
 #ifdef WITH_MHASH
-    fil->crc32=DB_CRC32&attr?"":NULL;
-    fil->crc32b=DB_CRC32B&attr?"":NULL;
-    fil->rmd128=DB_RMD128&attr?"":NULL;
-    fil->snefru=DB_SNEFRU&attr?"":NULL;
-    fil->gost=DB_GOST&attr?"":NULL;
-    fil->haval=DB_HAVAL&attr?"":NULL;
+    fil->crc32=DB_CRC32&attr?(byte*)"":NULL;
+    fil->crc32b=DB_CRC32B&attr?(byte*)"":NULL;
+    fil->gost=DB_GOST&attr?(byte*)"":NULL;
+    fil->haval=DB_HAVAL&attr?(byte*)"":NULL;
 #endif
   }
   listp=list_append(listp,(void*)fil);
@@ -504,7 +571,7 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
 	    if(a==NULL){
 	      a=new_seltree_node(tree,
 				 ((db_line*)file_lst->header->tail->data)
-				 ->filename);
+				 ->filename,0);
 	    }
 	    file_lst=traverse_tree(a,file_lst,attr);
 	  }
@@ -525,13 +592,12 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
 	    a=get_seltree_node(tree,
 			       ((db_line*)file_lst->header->tail->data)
 			       ->filename);
-	    if(a==NULL)
+	    if(a==NULL){
 	      a=new_seltree_node(tree,
 				 ((db_line*)file_lst->header->tail->data)
-				 ->filename);
-	    
-	    file_lst=traverse_tree(a,file_lst,
-				   matchattr);
+				 ->filename,0);
+	    }
+	    file_lst=traverse_tree(a,file_lst,matchattr); 
 	  }
 	}
       } else {
@@ -546,7 +612,7 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
   if(closedir(dirh)==-1){
     error(0,"Closedir() failed for %s\n",tree->path);
   };
-
+  
   #ifdef HAVE_READDIR_R
   free(resp);
   free(entp);
@@ -555,8 +621,9 @@ list* traverse_tree(seltree* tree,list* file_lst,int attr)
   /* All childs are not necessarily checked yet */
   if(tree->childs!=NULL){
     for(r=tree->childs;r;r=r->next){
-      if(!(((seltree*)r->data)->checked))
+      if(!(((seltree*)r->data)->checked)) {
 	file_lst=traverse_tree((seltree*)r->data,file_lst,attr);
+      }
     }
   }
   tree->checked=1;
@@ -569,19 +636,18 @@ list* gen_list(list* prxlist,list* nrxlist,list* erxlist)
   list* r=NULL;
   seltree* tree=NULL;
 
-  tree=new_seltree_node(NULL,"/");
+  tree=new_seltree_node(NULL,"/",0);
 
   gen_seltree(prxlist,tree,'s');
   gen_seltree(nrxlist,tree,'n');
   gen_seltree(erxlist,tree,'e');
-
-  if(tree==NULL)
-    return NULL;
   
-
+  if(tree==NULL){
+    return NULL;
+  }
+  
+  
   r=traverse_tree(tree,NULL,0);
   
   return r;
 }
-
-
