@@ -1,6 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
- * Copyright (C) 1999 Rami Lehti, Pablo Virolainen
+ * Copyright (C) 1999,2000 Rami Lehti, Pablo Virolainen
+ * $Header: /cvs-root-aide/aide/src/util.c,v 1.17 2000/04/20 12:44:59 rammer Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -38,10 +39,10 @@
 #define ISPRINT(c) (isascii(c) && isprint(c))
 
 static const char* url_name[] = { 
-  "file", "stdin", "stdout", "stderr", "fd"};
+  "file", "stdin", "stdout", "stderr", "fd", "sql" };
 
 static const int url_value[] = {
-  url_file, url_stdin, url_stdout,url_stderr,url_fd };
+  url_file, url_stdin, url_stdout,url_stderr,url_fd, url_sql };
 
 const int url_ntypes=sizeof(url_value)/sizeof(int);
 
@@ -96,7 +97,7 @@ url_t* parse_url(char* val)
       r+=2;
       for(i=0;r[0]!='/'&&r[0]!='\0';r++,i++);
       if(r[0]=='\0'){
-	error(10,"Invalid file-URL,no path after hostname: file:%s\n",t);
+	error(0,"Invalid file-URL,no path after hostname: file:%s\n",t);
 	return NULL;
       }
       u->value=strdup(r);
@@ -109,7 +110,7 @@ url_t* parse_url(char* val)
 	free(hostname);
 	break;
       } else {
-	error(10,"Invalid file-URL, cannot use hostname other than localhost or %s: file:%s\n",hostname,u->value);
+	error(0,"Invalid file-URL, cannot use hostname other than localhost or %s: file:%s\n",hostname,u->value);
 	free(hostname);
 	return NULL;
       }
